@@ -1,4 +1,3 @@
-
 import math
 from typing import Optional, Tuple
 
@@ -24,11 +23,7 @@ class HexagonPin(ExtrudeStraightShape):
         **kwargs
     ) -> None:
 
-        super().__init__(
-            name=name,
-            distance=distance,
-            **kwargs
-        )
+        super().__init__(name=name, distance=distance, **kwargs)
 
         self.center_point = center_point
         self.length_of_side = length_of_side
@@ -66,10 +61,10 @@ class HexagonPin(ExtrudeStraightShape):
 
         points = []
         for i in range(6):
-            point = (self.length_of_side * math.cos(math.pi / 3 * i) +
-                     self.center_point[0],
-                     self.length_of_side * math.sin(math.pi / 3 * i) +
-                     self.center_point[1])
+            point = (
+                self.length_of_side * math.cos(math.pi / 3 * i) + self.center_point[0],
+                self.length_of_side * math.sin(math.pi / 3 * i) + self.center_point[1],
+            )
             points.append(point)
 
         self.points = points
