@@ -10,10 +10,41 @@ from paramak import ExtrudeStraightShape
 
 class TestExtrudeStraightShape(unittest.TestCase):
     def setUp(self):
-        self.test_shape = ExtrudeStraightShape(
-            points=[(10, 10), (10, 30), (30, 30), (30, 10)], distance=30
+        self.test_shape = ExtrudeStraightShape(points=[(10, 10), (10, 30), (30, 30), (30, 10)], distance=30)
+
+    def test_bounding_box(self):
+        """checks the bounding box value"""
+
+        assert self.test_shape.bounding_box == (
+            (10.0, -15.0, 10.0),
+            (30.0, 15.0, 30.0),
         )
 
+    def test_largest_dimension(self):
+        """checks the largest dimension value"""
+
+        assert self.test_shape.largest_dimension == 25.0
+
+    def test_translate(self):
+        """Checks the shape extends to the bounding box and then translates
+        the shape and checks it is extended to the new bounding box"""
+
+        assert self.test_shape.solid.val().BoundingBox().xmax == 30
+        assert self.test_shape.solid.val().BoundingBox().ymax == 15
+        assert self.test_shape.solid.val().BoundingBox().zmax == 30
+        assert self.test_shape.solid.val().BoundingBox().xmin == 10
+        assert self.test_shape.solid.val().BoundingBox().ymin == -15
+        assert self.test_shape.solid.val().BoundingBox().zmin == 10
+
+        self.test_shape.translate = (1, 2, 3)
+
+        assert self.test_shape.solid.val().BoundingBox().xmax == 30 + 1
+        assert self.test_shape.solid.val().BoundingBox().xmin == 10 + 1
+        assert self.test_shape.solid.val().BoundingBox().ymax == 15 + 2
+        assert self.test_shape.solid.val().BoundingBox().ymin == -15 + 2
+        assert self.test_shape.solid.val().BoundingBox().zmax == 30 + 3
+        assert self.test_shape.solid.val().BoundingBox().zmin == 10 + 3
+
     def test_workplane_of_type_cadquery_plane(self):
         """Tests that a Cadquery.Plane is accepted as a workplane entry and
         makes a shape with the same volume as the default 'XY' workplane"""
@@ -130,14 +161,8 @@ class TestExtrudeStraightShape(unittest.TestCase):
         assert Path("test_solid2.stp").exists() is True
         assert Path("test_wire.stp").exists() is True
 
-        assert (
-            Path("test_solid.stp").stat().st_size
-            == Path("test_solid2.stp").stat().st_size
-        )
-        assert (
-            Path("test_wire.stp").stat().st_size
-            < Path("test_solid2.stp").stat().st_size
-        )
+        assert Path("test_solid.stp").stat().st_size == Path("test_solid2.stp").stat().st_size
+        assert Path("test_wire.stp").stat().st_size < Path("test_solid2.stp").stat().st_size
 
         os.system("rm test_solid.stp test_solid2.stp test_wire.stp")
 
